<p align="center"><img src="logo.png" alt="Chonker Logo" width="225" height="200"></p>

# Chonker: Data Utilities for NLP and Machine Learning

Welcome to Chonker! This code was assembled to provide a library to make data-intensive tasks just a little easier. Right now, Chonker is quite small: made up of one key module (wrangle) with one more currently in development (chonktorch). As a full-time student/researcher, 100% of this code develops from use in my ongoing projects. Chonker provides a neat package for myself and others who want to reuse convenient data functions instead of rebuilding them every time. If you somehow happen upon this library, I hope that something in here may be of use to you too!

## Modules
### chonker.wrangle
A module containing classes and functions designed to streamline data pre- and post-processing (i.e. wrangling)
### chonker.chonktorch (forthcoming)
A module for pre-built neural models for NLP, based off of my research and built on PyTorch

## License
Chonker is a work-in-progress with few guarantees. However, it is also open source and free to be modified and distributed, as long as those modifications remain free. As such, Chonker is licensed by the <a href=https://www.mozilla.org/en-US/MPL/2.0/FAQ>Mozilla Public License 2.0</a>.

## Contact
C.M. Downey

*cmdowney@uw.edu*

PhD Student

Department of Linguistics

University of Washington
